@@ -17,10 +17,10 @@
 from __future__ import annotations
 
 from abc import ABCMeta, abstractmethod
-from collections.abc import Iterable
+from collections.abc import AsyncIterable, Awaitable, Iterable
 from dataclasses import dataclass
 from datetime import timedelta
-from typing import Any, AsyncIterable, Awaitable, Callable, TypedDict, final
+from typing import Any, Callable, TypedDict, final
 
 from aiohomekit.characteristic_cache import CharacteristicCacheType
 from aiohomekit.model import Accessories, AccessoriesState, Transport
@@ -228,13 +228,6 @@ class AbstractPairing(metaclass=ABCMeta):
     async def unsubscribe(self, characteristics: Iterable[tuple[int, int]]) -> None:
         self.subscriptions.difference_update(characteristics)
 
-    async def reconnect_soon(self) -> None:
-        """
-        Notify the pairing that we have noticed a network change that means its connection maybe stale.
-
-        This will be removed in a future release.
-        """
-
     def dispatcher_availability_changed(
         self, callback: Callable[[bool], None]
     ) -> Callable[[], None]:
